@@ -7,7 +7,6 @@ import os
 
 import pytest
 from click.testing import CliRunner
-
 from tktl import main
 
 
@@ -38,17 +37,3 @@ def test_command_line_interface():
     assert "Show this message and exit." in help_result.output
 
 
-def test_ci_auth():
-    """Test the CLI."""
-    runner = CliRunner()
-    result = runner.invoke(main.login, ["--api-key", os.environ["TEST_API_KEY"]])
-    print(result.output)
-    assert result.exit_code == 0
-    assert result.output == "Login successful!\n"
-
-    result = runner.invoke(main.login, ["--api-key", "FAKEAPIKEY"])
-    assert result.exit_code == 0
-    assert result.output == "Request failed: Key format is invalid\n"
-    with open(os.path.expanduser("~/.tktl/config.json"), "r") as j:
-        d = json.load(j)
-    assert d["api-key"] == "FAKEAPIKEY"
