@@ -3,8 +3,7 @@ import os
 import pytest
 import requests
 from pydantic import BaseModel
-
-from tktl.core.clients.http_client import API, TaktileResponse
+from tktl.core.clients.http_client import API, interpret_response
 from tktl.core.config import settings
 from tktl.core.exceptions.exceptions import APIClientException
 from tktl.core.loggers import CliLogger
@@ -12,22 +11,21 @@ from tktl.core.managers.auth import AuthConfigManager
 
 
 def test_instantiate_api_client():
-    key = os.environ["TEST_API_KEY"]
+    key = os.environ["TEST_USER_API_KEY"]
     AuthConfigManager.set_api_key(key)
-    client = API(api_url=settings.DEPLOYMENT_API_HOST, logger=CliLogger())
-    assert client.api_key is not None
-    assert "X-Api-Key" in client.DEFAULT_HEADERS
-    assert client.DEFAULT_HEADERS["X-Api-Key"] == key
+    client = API(api_url=settings.DEPLOYMENT_API_URL, logger=CliLogger())
+    assert "X-Api-Key" in client.default_headers
+    assert client.default_headers["X-Api-Key"] == key
     assert (
         client.get_path(f"{settings.API_V1_STR}/deployments")
-        == f"{settings.DEPLOYMENT_API_HOST}{settings.API_V1_STR}/deployments"
+        == f"{settings.DEPLOYMENT_API_URL}{settings.API_V1_STR}/deployments"
     )
 
-    assert client.get_path() == f"{settings.DEPLOYMENT_API_HOST}"
+    assert client.get_path() == f"{settings.DEPLOYMENT_API_URL}"
 
 
 def test_request_failures():
-    client = API(api_url=settings.DEPLOYMENT_API_HOST, logger=CliLogger())
+    client = API(api_url=settings.DEPLOYMENT_API_URL, logger=CliLogger())
     response = client.post("non/existent/path")
     with pytest.raises(requests.exceptions.RequestException):
         response.raise_for_status()
@@ -50,10 +48,10 @@ def test_request_failures():
 
 
 def test_interpret_response():
-    client = API(api_url=settings.DEPLOYMENT_API_HOST, logger=CliLogger())
+    client = API(api_url=settings.DEPLOYMENT_API_URL, logger=CliLogger())
     response = client.post("non/existent/path")
     with pytest.raises(APIClientException) as e:
-        TaktileResponse.interpret_response(response, model=BaseModel)
+        interpret_response(response, model=BaseModel)
 
     client = API(api_url="https://jsonplaceholder.typicode.com/todos/1")
     response = client.get()
@@ -64,5 +62,5 @@ def test_interpret_response():
         title: str
         completed: bool
 
-    interpreted = TaktileResponse.interpret_response(response, TestModel)
+    interpreted = interpret_response(response, TestModel)
     assert interpreted.dict()["id"] == 1
