@@ -2,7 +2,6 @@ import json
 import os
 
 import pytest
-
 from tktl.commands.login import LogInCommand, SetApiKeyCommand
 from tktl.core.exceptions import InvalidInputError
 
@@ -14,17 +13,17 @@ def test_set_api_key(capsys):
     assert "API Key cannot be empty.\n" == err
 
     cmd.execute(api_key="ABC")
-    assert os.path.exists(os.path.expanduser("~/.tktl/config.json"))
-    with open(os.path.expanduser("~/.tktl/config.json"), "r") as j:
+    assert os.path.exists(os.path.expanduser("~/.config/tktl/config.json"))
+    with open(os.path.expanduser("~/.config/tktl/config.json"), "r") as j:
         d = json.load(j)
         assert d["api-key"] == "ABC"
 
 
-def test_login(capsys, user_password_key):
+def test_login(capsys):
     cmd = LogInCommand()
-    u, p, k = user_password_key
+    k = os.environ["TEST_USER_API_KEY"]
     assert cmd.execute(k) is True
     out, err = capsys.readouterr()
-    assert out == "Login successful!\n"
+    assert out == f"Authentication successful for user: {os.environ['TEST_USER']}\n"
     with pytest.raises(InvalidInputError):
         cmd.execute(None)
