@@ -2,7 +2,6 @@ import os
 import shutil
 
 import pytest
-
 from tktl.commands.init import init_project
 from tktl.commands.validate import validate_project_config
 from tktl.core.managers.constants import TEMPLATE_PROJECT_DIRS, TEMPLATE_PROJECT_FILES
@@ -17,8 +16,12 @@ def test_create_in_existing_directory(monkeypatch, tmpdir):
         assert os.path.isdir(os.path.join(tmpdir.dirpath(), "test_project_dir", d))
     for file in TEMPLATE_PROJECT_FILES:
         basename = file.replace("template/", "")
-        assert os.path.exists(os.path.join(tmpdir.dirpath(), "test_project_dir", basename))
-    assert os.path.exists(os.path.join(tmpdir.dirpath(), "test_project_dir", "tktl.yaml"))
+        assert os.path.exists(
+            os.path.join(tmpdir.dirpath(), "test_project_dir", basename)
+        )
+    assert os.path.exists(
+        os.path.join(tmpdir.dirpath(), "test_project_dir", "tktl.yaml")
+    )
 
 
 def test_create_project(create_proj):
