@@ -1,8 +1,9 @@
-from typing import Callable, Dict, List
+from typing import Callable, List
 
 import numpy as np
 import pandas as pd
 import pytest
+from pydantic import BaseModel
 
 from tktl import Tktl
 from tktl.core.exceptions.exceptions import ValidationException
@@ -21,14 +22,13 @@ def test_creation(X, y):
 
     @tktl.endpoint(X=X, y=y, kind="tabular")
     def predict(X):
-        return [0] * len(X)
+        return [0] * 3
 
     endpoint = tktl.endpoints[0]
-    assert type(endpoint.X) == pd.DataFrame
-    assert type(endpoint.y) == pd.Series
-    assert endpoint.y.name == "Outcome"
+    assert endpoint.input_schema.pandas_convertible is True
+    assert endpoint.output_schema.pandas_convertible is True
     pred = endpoint.func(pd.DataFrame(X))
-    assert pred.equals(pd.Series([0, 0, 0]))
+    assert pred == [0, 0, 0]
 
 
 @pytest.mark.parametrize("kind", ["tabular", "regression", "binary"])
@@ -42,21 +42,30 @@ def test_tabular_kinds(kind):
         return [0] * len(X)
 
     endpoint = tktl.endpoints[0]
-    assert isinstance(endpoint.X, pd.DataFrame)
-    assert isinstance(endpoint.y, pd.Series)
-    assert endpoint.y.name == "Outcome"
+    assert isinstance(endpoint.input_schema.value, pd.DataFrame)
+    assert isinstance(endpoint.output_schema.value, pd.Series)
     pred = endpoint.func(pd.DataFrame(X))
-    assert pred.equals(pd.Series([0, 0, 0]))
+    assert pred == [0, 0, 0]
 
 
-def test_auxiliary_kind():
+def test_custom_kind():
     tktl = Tktl()
 
-    @tktl.endpoint(kind="auxiliary")
-    def predict_untyped(x):
-        return x
+    with pytest.raises(ValueError):
+        # Must define either payload or X, y
+        @tktl.endpoint(kind="custom")
+        def predict_untyped(x):
+            return x
 
-    @tktl.endpoint(kind="auxiliary", payload_model=List[str], response_model=Dict)
+    class Payload(BaseModel):
+        a: List
+
+    class Response(BaseModel):
+        a: int
+        b: float
+        c: List
+
+    @tktl.endpoint(kind="custom", payload_model=Payload, response_model=Response)
     def predict_typed(x):
         return x
 
@@ -64,49 +73,65 @@ def test_auxiliary_kind():
         assert isinstance(endpoint.func, Callable)
         assert endpoint.func(["foo"]) == ["foo"]
 
+    x = pd.DataFrame([{'a': 1, 'b': 2}, {'a': 1, 'b': 2}, {'a': 1, 'b': 2}])
+    y = pd.Series([1, 2, 3])
+
+    @tktl.endpoint(kind="custom", X=x, y=y)
+    def predict_typed(x):
+        return x
+
+    schema = tktl.endpoints[1].input_schema.pydantic.schema()
+    assert schema['title'] == "DataFrame__predict_typed__input"
+    assert schema['example'] == [{'a': 1, 'b': 2}]
+
 
 def test_func_shape():
-    with pytest.raises(ValidationException):
-        tktl = Tktl()
-        X = {"a": [1, 2, 3]}
-        y = [4, 5, 5]
+    tktl = Tktl()
+    X = {"a": [1, 2, 3]}
+    y = [4, 5, 5]
 
-        @tktl.endpoint(X=X, y=y)
-        def predict(X):
-            return [0] * (len(X) - 1)
+    @tktl.endpoint(X=X, y=y)
+    def predict(X):
+        return [0] * (len(X) - 1)
+
+    assert tktl.endpoints[0].profiling_supported is False
 
 
 def test_input_shape():
-    with pytest.raises(ValidationException):
-        tktl = Tktl()
-        X = {"a": [1, 2, 3]}
-        y = [4, 5]
+    tktl = Tktl()
+    X = {"a": [1, 2, 3]}
+    y = [4, 5]
 
-        @tktl.endpoint(X=X, y=y)
-        def predict(X):
-            return [0] * len(X)
+    @tktl.endpoint(X=X, y=y)
+    def predict(X):
+        return [0] * len(X)
+
+    assert tktl.endpoints[0].profiling_supported is False
 
 
 def test_validate_func():
     tktl = Tktl()
 
-    with pytest.raises(ValidationException):
-        X = {"a": [1, 2, 3]}
-        y = [4, 5, 5]
+    X = {"a": [1, 2, 3]}
+    y = [4, 5, 5]
 
-        @tktl.endpoint(X=X, y=y, kind="regression")
-        def predict_regression(X):
-            return ["a", "b", "c"]  # must be numeric
+    @tktl.endpoint(X=X, y=y, kind="regression")
+    def predict_regression(X):
+        return ["a", "b", "c"]  # must be numeric
+
+    assert tktl.endpoints[0].profiling_supported is False
+
+    tktl = Tktl()
+    X = {"a": [1, 2, 3]}
+    y = [4, 5, 5]
 
     with pytest.raises(ValidationException):
-        tktl = Tktl()
-        X = {"a": [1, 2, 3]}
-        y = [4, 5, 5]
-
         @tktl.endpoint(X=X, y=y, kind="binary")
         def predict_binary(X):
             return [-2, 0, 1.5]  # must be in [0, 1]
 
+        _ = tktl.endpoints[0].profiling_supported
+
 
 def test_unknown_kind():
     with pytest.raises(ValidationException):
@@ -121,14 +146,15 @@ def test_unknown_kind():
 
 def test_missing():
     tktl = Tktl()
-    X = {"a": [1, 2, 3]}
+    X = pd.DataFrame({"a": [1, 2, 3]})
     y = pd.Series([0.1, 0.2, None])
 
-    with pytest.warns(UserWarning):
+    @tktl.endpoint(X=X, y=y, kind="regression")
+    def predict(X):
+        return [0] * len(X)
 
-        @tktl.endpoint(X=X, y=y, kind="regression")
-        def predict(X):
-            return [0] * len(X)
+    with pytest.warns(UserWarning):
+        tktl.endpoints[0].get_input_and_output_for_profiling()
 
 
 def test_large():
@@ -137,16 +163,23 @@ def test_large():
     X = pd.DataFrame({"a": np.random.uniform(size=n)})
     y = pd.Series(np.random.uniform(size=n))
 
+    @tktl.endpoint(X=X, y=y, kind="regression")
+    def predict(X):
+        return [0] * len(X)
+
     with pytest.warns(UserWarning):
-
-        @tktl.endpoint(X=X, y=y, kind="regression")
-        def predict(X):
-            return [0] * len(X)
+        tktl.endpoints[0].get_input_and_output_for_profiling()
 
 
-def test_auxiliary():
+def test_custom():
     tktl = Tktl()
 
-    @tktl.endpoint(kind="auxiliary", payload_model=List[str], response_model=List[str])
+    class Payload(BaseModel):
+        a: str
+
+    class Response(BaseModel):
+        a: str
+
+    @tktl.endpoint(kind="custom", payload_model=Payload, response_model=Response)
     def string_endpoint(x):
         return x
