@@ -1,6 +1,6 @@
 import abc
 
-from tktl.core.clients.http_client import API
+from tktl.core.clients import TaktileClient
 from tktl.core.config import settings
 from tktl.core.loggers import CliLogger
 
@@ -16,7 +16,7 @@ class BaseApiCommand:
     __metaclass__ = abc.ABCMeta
 
     def __init__(
-        self, logger=CliLogger(), api_url=settings.TAKTILE_API_HOST,
+        self, logger=CliLogger(), api_url=settings.DEPLOYMENT_API_URL,
     ):
         self.api_url = api_url
         self.logger = logger
@@ -27,12 +27,20 @@ class BaseApiCommand:
         pass
 
     def _get_client(self):
-        return API(api_url=settings.DEPLOYMENT_API_HOST, logger=self.logger)
+        return TaktileClient(api_url=self.api_url, logger=self.logger)
 
 
 class BaseDeploymentApiCommand(BaseApiCommand):
     def __init__(self):
-        super().__init__(api_url=settings.DEPLOYMENT_API_HOST)
+        super().__init__(api_url=settings.DEPLOYMENT_API_URL)
+
+    def execute(self, *args, **kwargs):
+        raise NotImplementedError
+
+
+class BaseTaktileApiCommand(BaseApiCommand):
+    def __init__(self):
+        super().__init__(api_url=settings.TAKTILE_API_URL)
 
     def execute(self, *args, **kwargs):
         raise NotImplementedError
