@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Set, List, Iterable
+from typing import Iterable, List, Set
 
 
 class ExtendedEnum(Enum):
