@@ -10,12 +10,12 @@ class Settings(BaseSettings):
     IN_TESTING = False
 
     DEBUG: bool = False
-    WEB_UR: str = "www.taktile.com"
-    TAKTILE_API_HOST: str = "http://taktile-api.local.taktile.com"
-    DEPLOYMENT_API_HOST: str = "http://deployment-api.local.taktile.com"
-    LOG_HOST: str = "http://logs.local.taktile.com"
+    WEB_URL: str = "https://app.taktile.com"
+    TAKTILE_API_URL: str = "https://taktile-api.taktile.com"
+    DEPLOYMENT_API_URL: str = "https://deployment-api.taktile.com"
+    LOG_HOST: str = "https://logs.taktile.com"
 
-    TKTL_CONFIG_PATH: str = os.path.expanduser("~/.tktl")
+    TKTL_CONFIG_PATH: str = os.path.expanduser("~/.config/tktl")
     CONFIG_FILE_NAME: str = "config.json"
     TAKTILE_API_KEY: str = None
     HELP_HEADERS_COLOR: str = "yellow"
