@@ -1,4 +1,7 @@
+from typing import Union
+
 from tktl.core import ExtendedEnum
+from tktl.core.schemas.repository import Endpoint, Repository, RepositoryDeployment
 
 
 class UserRepoConfigFileNameT(str, ExtendedEnum):
@@ -61,3 +64,25 @@ class InstanceTypeT(str, ExtendedEnum):
 class ServiceT(str, ExtendedEnum):
     REST = "rest"
     GRPC = "grpc"
+
+
+class EndpointKinds(str, ExtendedEnum):
+    CUSTOM = "custom"
+    TABULAR = "tabular"
+    BINARY = "binary"
+    REGRESSION = "regression"
+    MULTICLASS = "multiclass"
+
+
+class RestSchemaTypes(ExtendedEnum):
+    DICT = "Dict"
+    SEQUENCE = "Sequence"
+    ARRAY = "Array"
+    FLAT_ARRAY = "FlatArray"
+    SERIES = "Series"
+    DATAFRAME = "DataFrame"
+    SINGLE_VALUE = "SingleValue"
+    CUSTOM_MODEL = "CustomModel"
+
+
+Resources = Union[Repository, RepositoryDeployment, Endpoint]
