@@ -1,4 +1,7 @@
+import functools
+import itertools
 import os
+import time
 
 from tktl.core.exceptions import WrongPathError
 
@@ -51,3 +54,26 @@ class PathParser(object):
     @staticmethod
     def is_s3_url(path):
         return not os.path.exists(path) and path.lower().startswith("s3:")
+
+
+def lru_cache(timeout: int, maxsize: int = 128, typed: bool = False):
+    def wrapper_cache(func):
+        func = functools.lru_cache(maxsize=maxsize, typed=typed)(func)
+        func.delta = timeout * 10 ** 9
+        func.expiration = time.monotonic_ns() + func.delta
+
+        @functools.wraps(func)
+        def wrapped_func(*args, **kwargs):
+            if time.monotonic_ns() >= func.expiration:
+                func.cache_clear()
+                func.expiration = time.monotonic_ns() + func.delta
+            return func(*args, **kwargs)
+
+        wrapped_func.cache_info = func.cache_info
+        wrapped_func.cache_clear = func.cache_clear
+        return wrapped_func
+
+    return wrapper_cache
+
+
+flatten = lambda x: list(itertools.chain.from_iterable(x))
