@@ -4,7 +4,7 @@ from functools import wraps
 import requests
 
 from tktl.core.config import settings
-from tktl.core.exceptions import AuthenticationError, InvalidInputError
+from tktl.core.exceptions import InvalidInputError
 from tktl.core.loggers import CliLogger
 from tktl.core.managers.auth import AuthConfigManager
 from tktl.core.strings import CLIStrings, HeaderStrings
@@ -73,15 +73,16 @@ def logout():
     return True
 
 
-def validate_key(suppress=False):
-    key = AuthConfigManager.get_api_key()
-    if not key:
+def validate_key(suppress=False, api_key=None):
+    if not api_key:
+        api_key = AuthConfigManager.get_api_key()
+    if not api_key:
         logger.error(CLIStrings.AUTH_ERROR_MISSING_KEY)
-        raise AuthenticationError(CLIStrings.AUTH_ERROR_MISSING_KEY)
+        return False
 
     r = requests.get(
-        f"{settings.TAKTILE_API_HOST}{settings.API_V1_STR}/users/me",
-        headers={"Accept": HeaderStrings.APPLICATION_JSON, "X-Api-Key": key},
+        f"{settings.TAKTILE_API_URL}{settings.API_V1_STR}/users/me",
+        headers={"Accept": HeaderStrings.APPLICATION_JSON, "X-Api-Key": api_key},
     )
     try:
         r.raise_for_status()
@@ -97,7 +98,8 @@ def validate_key(suppress=False):
 def validate_decorator(func):
     @wraps(func)
     def wrapped_validation(*args, **kwargs):
-        validate_key(suppress=True)
+        if not validate_key(suppress=True):
+            return
         return func(*args, **kwargs)
 
     return wrapped_validation
