@@ -2,10 +2,11 @@ import click
 import click_completion
 import requests
 
-from tktl.cli import common
-from tktl.cli.auth import login, logout, save_api_key
-from tktl.cli.deployments import deployments
+from tktl.cli.common import ClickGroup
+from tktl.cli.delete import delete as delete_commands
+from tktl.cli.get import get as get_commands
 from tktl.cli.init import init
+from tktl.cli.login import login, logout
 from tktl.cli.validate import validate
 from tktl.commands.version import get_version
 from tktl.core.config import settings
@@ -15,7 +16,7 @@ from tktl.core.loggers import CliLogger
 click_completion.init()
 
 
-class TaktileGroup(common.ClickGroup):
+class TaktileGroup(ClickGroup):
     def main(self, *args, **kwargs):
         try:
             super(TaktileGroup, self).main(*args, **kwargs)
@@ -40,7 +41,8 @@ def cli():
 cli.add_command(get_version)
 cli.add_command(logout)
 cli.add_command(login)
-cli.add_command(save_api_key)
 cli.add_command(init)
-cli.add_command(deployments)
+cli.add_command(get_version)
+cli.add_command(delete_commands)
+cli.add_command(get_commands)
 cli.add_command(validate)
